@@ -7,47 +7,37 @@
 # nor does it submit to any jurisdiction.
 #
 
-import sys
-
-try:
-    import ecmwflibs
-# TODO: update when the version of Magics on conda is compatible with climetlab
-# except ModuleNotFoundError:
-#    # we rely on the library (libMagPlus) installed otherwise
-#    pass
-except Exception as e:
-    print(
-        f"Error importing ecmwflibs. Magics and/or eccodes may not be fonctionning? {e}",
-        file=sys.stderr,
-    )
-
-from climetlab.datasets import Dataset
-from climetlab.sources import DataSource
-
 from .core.caching import CACHE as cache
 from .core.metadata import init_metadata
 from .core.settings import SETTINGS as settings
-from .datasets import dataset, load_dataset
+from .datasets import Dataset, dataset, load_dataset, register_dataset
+from .helpers import Helper
 from .plotting import interactive_map, new_plot
 from .plotting import options as plotting_options
 from .plotting import plot_map
-from .sources import load as load_source
+from .readers import Reader
+from .sources import Source, load_source, register_source, source
 
-__version__ = "0.4.6"
+__version__ = "0.5.3"
 
 
 __all__ = [
-    "load_source",
-    "load_dataset",
-    "dataset",
-    "plot_map",
-    "interactive_map",
-    "new_plot",
-    "settings",
     "cache",
+    "dataset",
     "Dataset",
-    "DataSource",
+    "Helper",
+    "interactive_map",
+    "load_dataset",
+    "load_source",
+    "new_plot",
+    "plot_map",
     "plotting_options",
+    "Reader",
+    "settings",
+    "source",
+    "Source",
+    "register_dataset",
+    "register_source",
 ]
 
 init_metadata()
