@@ -7,7 +7,6 @@
 # nor does it submit to any jurisdiction.
 #
 
-import inspect
 import os
 from importlib import import_module
 
@@ -15,7 +14,8 @@ import yaml
 
 import climetlab
 from climetlab.core.metadata import annotate
-from climetlab.core.plugins import find_plugin
+from climetlab.core.plugins import find_plugin, register
+from climetlab.utils import consume_args
 from climetlab.utils.html import table
 
 
@@ -95,31 +95,31 @@ def _module_callback(plugin):
     return import_module(plugin, package=__name__).dataset
 
 
+def camel(name):
+    return "".join(x[0].upper() + x[1:].lower() for x in name.split("-"))
+
+
 class YamlDefinedDataset(Dataset):
-    def __init__(self, path, dataset):
-        self._path = path
-        for k, v in dataset.get("metadata", {}).items():
-            setattr(self, k, v)
-        self._src = dataset["source"]
-        self._args = dataset.get("args", {})
+    def __init__(self):
+        self.source = climetlab.load_source(self._src, **self._args)
 
     def __call__(self):
-        self.source = climetlab.load_source(self._src, **self._args)
         return self
 
-    def __repr__(self):
-        return f"YAML[{self._path}]"
-
 
 class DatasetLoader:
 
     kind = "dataset"
 
     def load_yaml(self, path):
+        name, _ = os.path.splitext(os.path.basename(path))
         with open(path) as f:
-            return YamlDefinedDataset(
-                path, yaml.load(f.read(), Loader=yaml.SafeLoader)["dataset"]
+            dataset = yaml.load(f.read(), Loader=yaml.SafeLoader)["dataset"]
+            attributes = dataset.get("metadata", {})
+            attributes.update(
+                dict(_path=path, _src=dataset["source"], _args=dataset.get("args", {}))
             )
+            return type(camel(name), (YamlDefinedDataset,), attributes)
 
     def load_module(self, module):
         return import_module(module, package=__name__).dataset
@@ -128,17 +128,32 @@ class DatasetLoader:
         return entry.load().dataset
 
 
+def register_dataset(module):
+    register("dataset", module)
+
+
 class DatasetMaker:
-    def __call__(self, name, *args, **kwargs):
+    def lookup(self, name, *args, **kwargs):
+
         loader = DatasetLoader()
         klass = find_plugin(os.path.dirname(__file__), name, loader)
 
-        dataset = klass(*args, **kwargs)
+        (args1, kwargs1, args2, kwargs2) = consume_args(
+            klass,
+            getattr(klass, "_load", None),
+            *args,
+            **kwargs,
+        )
+
+        dataset = klass(*args1, **kwargs1)
 
         if getattr(dataset, "name", None) is None:
             dataset.name = name
 
-        return dataset
+        return dataset.mutate(), args2, kwargs2
+
+    def __call__(self, name, *args, **kwargs):
+        return self.lookup(name, *args, **kwargs)[0]
 
     def __getattr__(self, name):
         return self(name.replace("_", "-"))
@@ -150,11 +165,15 @@ TERMS_OF_USE_SHOWN = set()
 
 
 def load_dataset(name, *args, **kwargs):
-    ds = dataset(name, *args, **kwargs)
+
+    ds, args, kwargs = dataset.lookup(name, *args, **kwargs)
 
     if name not in TERMS_OF_USE_SHOWN:
         if ds.terms_of_use is not None:
             print(ds.terms_of_use)
         TERMS_OF_USE_SHOWN.add(name)
 
+    if getattr(ds, "_load", None):
+        ds._load(*args, **kwargs)
+
     return ds.mutate()
