@@ -12,7 +12,7 @@ import weakref
 from importlib import import_module
 
 from climetlab.core.caching import cache_file
-from climetlab.core.plugins import find_plugin
+from climetlab.core.plugins import find_plugin, register
 from climetlab.utils.html import table
 
 
@@ -46,7 +46,11 @@ class SourceMaker:
 source = SourceMaker()
 
 
-def load(name, *args, **kwargs):
+def register_source(module):
+    register("source", module)
+
+
+def load_source(name, *args, **kwargs):
     return source(name, *args, **kwargs).mutate()
 
 
@@ -69,7 +73,7 @@ def list_entries():
     return result
 
 
-class DataSource:
+class Source:
     """
     Doc
     """
