@@ -12,7 +12,7 @@ import os
 
 import ecmwfapi
 
-from climetlab.decorators import parameters
+from climetlab.normalize import normalize_args
 
 from .base import APIKeyPrompt, FileSource
 
@@ -83,10 +83,10 @@ class MARSRetriever(FileSource):
             service("mars").execute(request, self.path + ".tmp")
             os.rename(self.path + ".tmp", self.path)
 
-    @parameters(
-        param=("parameter-list", "mars"),
-        date=("date-list", "%Y-%m-%d"),
-        area=("bounding-box", list),
+    @normalize_args(
+        param="variable-list(mars)",
+        date="date-list(%Y-%m-%d)",
+        area="bounding-box(list)",
     )
     def request(self, **kwargs):
         return kwargs
