@@ -18,4 +18,7 @@ def test_netcdf():
 
 
 if __name__ == "__main__":
-    test_netcdf()
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
