@@ -22,10 +22,7 @@ from nbconvert.preprocessors import ExecutePreprocessor
 
 EXAMPLES = os.path.join(os.path.dirname(os.path.dirname(__file__)), "docs", "examples")
 
-SKIP = (
-    "11-icoads.ipynb",
-    "12-external-plugins.ipynb",
-)
+SKIP = ("11-icoads.ipynb",)
 
 MARS = (
     "04-source-mars.ipynb",
@@ -87,3 +84,10 @@ def test_notebook(path):
 
     proc = ExecutePreprocessor(timeout=60 * 60, kernel_name="python3")
     proc.preprocess(nb, {"metadata": {"path": EXAMPLES}})
+
+
+if __name__ == "__main__":
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
